Logistic-package: Binomial Logistic Regression

Description Details Author(s) Examples

Description

Use logistic regression model to predict binary output (like 0 & 1, a & b)

Details

There are two functions in the package, Logreg and My_predict. The Logreg function fits binomial logistic models. The My_predict function provides the default fitting method for Logreg. It is similar to glm in the glm2 package, except for modifications to the computational method that provide more stable convergence.

Author(s)

Chang Wang (wangchan@umich.edu)

Maintainer: Chang Wang <wangchan@umich.edu>

Examples

1
2
3
4
  ## Not run: 
     Refer to vignette for detailed examples
  
## End(Not run)

hobbitish1028/Logistic documentation built on Nov. 26, 2019, 8:58 a.m.