Description Details Author(s) Examples
Use logistic regression model to predict binary output (like 0 & 1, a & b)
There are two functions in the package, Logreg and My_predict. The Logreg function fits binomial logistic models. The My_predict function provides the default fitting method for Logreg. It is similar to glm in the glm2 package, except for modifications to the computational method that provide more stable convergence.
Chang Wang (wangchan@umich.edu)
Maintainer: Chang Wang <wangchan@umich.edu>
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.